@@ -1,6 +1,7 @@
 /* uid_hash.h
  *
  * protos & c.
+ *
  */
 
-char *uid_name (int);
+char *uid_name PARAMS((int));
